@@ -1,6 +1,6 @@
 /*
  ╔════════╦═══════════════════════╦════════╗
- ║        ║      AI MANAGER       ║        ║
+ ║        ║     VectorizeList     ║        ║
  ║   ___  ╚═══════════════════════╝  ___   ║
  ║  (o o)                           (o o)  ║
  ║ (  V  )  Julien Calenge © 2023  (  V  ) ║
